#
# spec file for package CharLS
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 2
Name:           CharLS
Version:        2.2.0
Release:        bp154.1.39
Summary:        A JPEG-LS library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/team-charls/charls/
Source0:        https://github.com/team-charls/charls/archive/%{version}.tar.gz#/charls-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1320
BuildRequires:  gcc-c++
%else
# Leap 42.2+ / SLE12SP2Backports
BuildRequires:  gcc6-c++
#!BuildIgnore:  libgcc_s1
%endif

%description
An optimized implementation of the JPEG-LS standard for lossless and
near-lossless image compression. JPEG-LS is a low-complexity standard that
matches JPEG 2000 compression ratios. In terms of speed, CharLS outperforms
open source and commercial JPEG LS implementations.

%package devel
Summary:        Libraries and headers for CharLS
Group:          Development/Libraries/C and C++
Requires:       libcharls%{so_ver} = %{version}

%description devel
This package contains libraries and headers for CharLS.

%package -n libcharls%{so_ver}
Summary:        A JPEG-LS library
Group:          System/Libraries

%description -n libcharls%{so_ver}
An optimized implementation of the JPEG-LS standard for lossless and
near-lossless image compression. JPEG-LS is a low-complexity standard that
matches JPEG 2000 compression ratios. In terms of speed, CharLS outperforms
open source and commercial JPEG LS implementations.

%prep
%setup -q -n charls-%{version}

%build
%if 0%{?suse_version} <= 1320
test -x "$(type -p gcc-5)" && export CC=gcc-5
test -x "$(type -p g++-5)" && export CXX=g++-5
test -x "$(type -p gcc-6)" && export CC=gcc-6
test -x "$(type -p g++-6)" && export CXX=g++-6
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7
%endif
%cmake \
 -DBUILD_SHARED_LIBS=ON \
 -DBUILD_TESTING=ON
%make_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:.
ctest .

%post -n libcharls%{so_ver} -p /sbin/ldconfig
%postun -n libcharls%{so_ver} -p /sbin/ldconfig

%files devel
%license LICENSE.md
%doc CHANGELOG.md README.md
%{_includedir}/charls/
%{_libdir}/*.so
%{_libdir}/cmake/charls/
%{_libdir}/pkgconfig/*.pc

%files -n libcharls%{so_ver}
%{_libdir}/libcharls.so.%{so_ver}*

%changelog
* Mon Mar  1 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 2.2.0:
  * Added
  - Added pkg-config charls.pc file to help in detect the CharLS
    library (see #76)
  - Added standard CMake variable BUILD_SHARED_LIBS as an option
    to make it visible in the CMake GUI (see #66)
  - The PowerPC Little Endian (ppc64le) platform has been added
    as supported architecture
  * Fixed
  - Fixed #21, Building with UBSAN, will report runtime error:
    left shift of 4031 by 63 places cannot be represented in type
    'long int'
  - Fixed #25, CharLS fails to read LSE marker segment after
    first SOS segment
  - Fixed #26, CharLS should only use the valid bits from the
    passed input buffer
  - Fixed #36, CharLS should remain stable from bad input
    (several issues found by fuzzy testing)
  - Fixed #60, Visual Studio 2015 C++ compiler cannot compile
    certain constexpr constructions
  - Fixed #62, Missing includes in jpegls_error.cpp when using
    libc++ (and not libstdc++)
  - Fixed #70, The C and C++ sample don't swap the pixels from a
    .bmp file horizontal
  - Fixed #79, Wrong JPEG-LS encoding when stride is non-default
    (stride != 0), component count > 1 and interleave_mode is none
  * Changed
  - The API has been extended with additional annotations to
    assist the static analyzer in the MSVC and GCC/clang
    compilers
  - The size check for a Start Of Scan (SOS) segment is now exact
    for improved compatibility with fuzzy testing
  - The minimum support version of CMake is now 3.13 (was 3.9),
    3.13 is needed for add_link_options
  - The Windows static library and DLL are now compiled with the
    Control Flow Guard (/guard:cf) option enabled for enhanced
    security
  - The .NET adapter has been upgraded to .NET 5 and moved to its
    own repository This has been done to make it possible to have
    different release cycles.
  * Removed
  - The legacy methods JpegLsEncodeStream, JpegLsDecodeStream and
    JpegLsReadHeaderStream have been removed as exported methods.
    These methods were not part of the public API and only used
    by by the charlstest application
- Added pkgconfig build requires.
* Sun Aug  9 2020 andy great <andythe_great@pm.me>
- Update to version 2.1.0.
  * Added
  * Two new C++ classes (jpegls_encoder \ jpegls_decoder) have
    been added to make it much easier to use CharLS from C++
  * A new C API (charls_xxx functions) was added to provide a
    more stable ABI for future updates. The old API calls are
    internally forwarded to the new API.
  * CharLS can now read and write JPEG-LS standard SPIFF headers
  * Support has been added to detect the unsupported JPEG-LS
    extension (ISO/IEC 14495-2) SOF_57 marker and IDs in LSE
    marker
  * Support has been added to encode\decode 4 component images
    in all interleave modes
  * Deprecated
  * The legacy 1.x\2.0 C API has been marked as deprecated. This
    legacy API will be maintained until the next major upgrade.
  * Future 2.x updates will start to mark the legacy types and
    functions with the C++ [[deprecated]] attribute.
  * Changed
  * charls_error has been replaced by a C++11 compatible
    jpegls_errc error code enum design
  * The included C and C++ sample have been updated to use the
    new C\C++ API
  * Improved the validation of the JPEG-LS stream during
    decoding
  * The referenced NuGet packages of the .NET wrapper assembly
    are updated to their latest versions
  * Removed
  * Support to write JFIF headers during encoding has been
    removed. JFIF headers were already skipped when present
    during decoding.
  * SPIFF headers should be used when creating standalone .jls
    files
  * Support for .NET Code Contracts has been removed as this
    technology is being phased out by Microsoft
  * Fixed
  * Fixed #7, How to compile CharLS with Xcode has been
    documented in the Wiki
  * Fixed #44, Only the API functions should be exported from a
    Linux shared library
  * Fixes #35, Encoding will fail if the bit per sample is
    greater than 8, and a custom RESET value is used
  * Fixes #51, The default threshold values are not corrected
    computed for 6 bit images or less
  * Fixed the ASSERT in the ModuloRange function, which would
    trigger false assertions in debug builds
* Thu Jul 13 2017 olaf@aepfle.de
- Build with gcc6, fix build failure for Leap
* Mon Jul 10 2017 jengelh@inai.de
- Fix RPM group.
* Thu Jul  6 2017 asterios.dramis@gmail.com
- Update to version 2.0.0:
  Bug fixes
  * #10 - Fixed the problem that "output buffer to small" was not
    detected when writting encoded bytes to a fixed output buffer.
    This could cause memory corruption problems.
  * #11 - Update charlstest to return EXIT_SUCCESS/FAILURE
  * Fixed the issue that DecodeToPnm would set
    params.colorTransform = ColorTransformation::BigEndian but the
    library didn’t support this option during decoding.
  Misc
  * Updated the source code to C++ v14.
  * Refactored several API's to make usage of the library easier.
- Removed unzip build requirement (not needed anymore).
- Require gcc >= 5.0 (for C++ v14).
- Removed the following patches (not needed anymore):
  charls_add_cmake_install_target.patch
  charls_add_sharedlib_soname.patch
  charls_fix_tests.patch
* Tue Nov 20 2012 cgiboudeaux@gmx.com
- Fix the SLES build (%%make_install is not expanded)
* Mon Dec  5 2011 cfarrell@suse.com
- license update: BSD-3-Clause
  The License file is BSD-3-Clause. Also, use SPDX format
* Fri Dec  2 2011 asterios.dramis@gmail.com
- Initial release (version 1.0).
- Added three patches (taken from Fedora):
  * charls_add_cmake_install_target.patch: Add a cmake install target for
    CharLS header files.
  * charls_add_sharedlib_soname.patch: Add soname to generated shared lib and
    install libCharLS.so.
  * charls_fix_tests.patch: Fix tests.
